@@ -19,7 +19,7 @@ void sudokus_to_svg(char *filename, t_sudoku sudokus[4]) {
 	float thickLineWidth = 0.5, thinLineWidth = 0.2;
 	int titleFontSz = 40, sudokuFontSz = 12, numberFontSz = 24;
 	char sudTitle[512];
-	char fn[516] = "sudoku.svg";
+	char fn[516] = "sudoku";
 	
 	// at least one square width between sudokus
 	int size = sudokus[0].size;
